@@ -6,7 +6,7 @@ __version__='3.3.0'
 __doc__='''Core of the graphics library - defines Drawing and Shapes'''
 
 import os, sys
-from math import pi, cos, sin, tan, sqrt
+from math import pi, cos, sin, tan, sqrt, radians, floor
 from pprint import pprint
 
 from reportlab.platypus import Flowable
@@ -637,10 +637,27 @@ class Drawing(Group, Flowable):
     This has no properties except a height, width and list
     of contents."""
 
-    _saveModes=(
-            'pdf','ps','eps','gif','png','jpg','jpeg','pct',
-            'pict','tiff','tif','py','bmp','svg','tiffp','tiffl','tiff1',
-            )
+    _saveModes = {
+            'bmp',
+            'eps',
+            'gif',
+            'jpeg',
+            'jpg',
+            'pct',
+            'pdf',
+            'pict',
+            'png',
+            'ps',
+            'py',
+            'svg',
+            'tif',
+            'tiff',
+            'tiff1',
+            'tiffl',
+            'tiffp',
+            }
+
+    _bmModes = _saveModes - {'eps','pdf','ps','py','svg'}
 
     _xtraAttrMap = AttrMap(
         width = AttrMapValue(isNumber,desc="Drawing width in points."),
@@ -658,8 +675,7 @@ class Drawing(Group, Flowable):
 
     _attrMap = AttrMap(BASE=Group,
             formats = AttrMapValue(SequenceOf(
-                OneOf('pdf','gif','png','tif','jpg','tiff','pct','pict',
-                        'bmp','tiffp','tiffl','tiff1','eps','svg','ps','py'),
+                OneOf(*_saveModes),
                 lo=1,emptyOK=0), desc='One or more plot modes'),
             )
     _attrMap.update(_xtraAttrMap)
@@ -779,7 +795,7 @@ class Drawing(Group, Flowable):
                 macfs.FSSpec(filename).SetCreatorType("CARO", "PDF ")
                 macostools.touched(filename)
 
-        for bmFmt in ('gif','png','tif','jpg','tiff','pct','pict', 'bmp','tiffp','tiffl','tiff1'):
+        for bmFmt in self._bmModes:
             if bmFmt in plotMode:
                 from reportlab.graphics import renderPM
                 filename = '%s.%s' % (fnroot,bmFmt)
@@ -843,13 +859,13 @@ class Drawing(Group, Flowable):
 
     def asString(self, format, verbose=None, preview=0, **kw):
         """Converts to an 8 bit string in given format."""
-        assert format in ('pdf','ps','eps','gif','png','jpg','jpeg','bmp','ppm','tiff','tif','py','pict','pct','tiffp','tiffl','tiff1'), 'Unknown file format "%s"' % format
+        assert format in self._saveModes, 'Unknown file format "%s"' % format
         from reportlab import rl_config
         #verbose = verbose is not None and (verbose,) or (getattr(self,'verbose',verbose),)[0]
         if format == 'pdf':
             from reportlab.graphics import renderPDF
             return renderPDF.drawToString(self)
-        elif format in ('gif','png','tif','tiff','jpg','pct','pict','bmp','ppm','tiffp','tiffl','tiff1'):
+        elif format in self._bmModes:
             from reportlab.graphics import renderPM
             return renderPM.drawToString(self, fmt=format,showBoundary=getattr(self,'showBorder',
                             rl_config.showBoundary),**_extraKW(self,'_renderPM_',**kw))
@@ -867,6 +883,9 @@ class Drawing(Group, Flowable):
             return renderPS.drawToString(self, showBoundary=getattr(self,'showBorder',rl_config.showBoundary))
         elif format == 'py':
             return self._renderPy()
+        elif format == 'svg':
+            from reportlab.graphics import renderSVG
+            return renderSVG.drawToString(self,showBoundary=getattr(self,'showBorder',rl_config.showBoundary),**_extraKW(self,'_renderSVG_',**kw))
 
     def resized(self,kind='fit',lpad=0,rpad=0,bpad=0,tpad=0):
         '''return a base class drawing which ensures all the contents fits'''
@@ -909,6 +928,11 @@ class _DrawingEditorMixin:
         else:
             raise ValueError("Can't add, need name")
 
+class isStrokeDashArray(Validator):
+    def test(self,x):
+        return isListOfNumbersOrNone.test(x) or (isinstance(x,(list,tuple)) and isNumber(x[0]) and isListOfNumbers(x[1]))
+isStrokeDashArray = isStrokeDashArray()
+
 class LineShape(Shape):
     # base for types of lines
 
@@ -918,7 +942,7 @@ class LineShape(Shape):
         strokeLineCap = AttrMapValue(OneOf(0,1,2),desc="Line cap 0=butt, 1=round & 2=square"),
         strokeLineJoin = AttrMapValue(OneOf(0,1,2),desc="Line join 0=miter, 1=round & 2=bevel"),
         strokeMiterLimit = AttrMapValue(isNumber,desc="miter limit control miter line joins"),
-        strokeDashArray = AttrMapValue(isListOfNumbersOrNone,desc="a sequence of numbers represents on and off, e.g. (2,1)"),
+        strokeDashArray = AttrMapValue(isStrokeDashArray,desc="[numbers] or [phase,[numbers]]"),
         strokeOpacity = AttrMapValue(isOpacity,desc="The level of transparency of the line, any real number betwen 0 and 1"),
         strokeOverprint = AttrMapValue(isBoolean,desc='Turn on stroke overprinting'),
         overprintMask = AttrMapValue(isBoolean,desc='overprinting for ordinary CMYK',advancedUsage=1),
@@ -1091,7 +1115,6 @@ EmptyClipPath=Path()    #special path
 def getArcPoints(centerx, centery, radius, startangledegrees, endangledegrees, yradius=None, degreedelta=None, reverse=None):
     if yradius is None: yradius = radius
     points = []
-    from math import sin, cos, pi
     degreestoradians = pi/180.0
     startangle = startangledegrees*degreestoradians
     endangle = endangledegrees*degreestoradians
@@ -1298,7 +1321,6 @@ class Wedge(SolidShape):
         yradius, radius1, yradius1 = self._xtraRadii()
         startangledegrees = self.startangledegrees
         endangledegrees = self.endangledegrees
-        from math import sin, cos, pi
         degreestoradians = pi/180.0
         startangle = startangledegrees*degreestoradians
         endangle = endangledegrees*degreestoradians
@@ -1410,6 +1432,94 @@ class PolyLine(LineShape):
     def getBounds(self):
         return getPointsBounds(self.points)
 
+class Hatching(Path):
+    '''define a hatching of a set of polygons defined by lists of the form [x0,y0,x1,y1,....,xn,yn]'''
+
+    _attrMap = AttrMap(BASE=Path,
+        xyLists = AttrMapValue(EitherOr((isListOfNumbers,SequenceOf(isListOfNumbers,lo=1)),"xy list(s)"),desc="list(s) of numbers in the form x1, y1, x2, y2 ... xn, yn"),
+        angles = AttrMapValue(EitherOr((isNumber,isListOfNumbers,"angle(s)")),desc="the angle or list of angles at which hatching lines should be drawn"),
+        spacings = AttrMapValue(EitherOr((isNumber,isListOfNumbers,"spacings(s)")),desc="orthogonal distance(s) between hatching lines"),
+        )
+
+    def __init__(self, spacings=2, angles=45, xyLists=[], **kwds):
+        Path.__init__(self, **kwds)
+        if isListOfNumbers(xyLists):
+            xyLists  = (xyLists,)
+        if isNumber(angles):
+            angles = (angles,)  #turn into a sequence
+        if isNumber(spacings):
+            spacings = (spacings,)  #turn into a sequence
+        i = len(angles)-len(spacings)
+        if i>0:
+            spacings = list(spacings)+i*[spacings[-1]]
+
+        self.xyLists = xyLists
+        self.angles = angles
+        self.spacings = spacings
+
+        moveTo = self.moveTo
+        lineTo = self.lineTo
+
+        for i, theta in enumerate(angles):
+            spacing = spacings[i]
+            theta = radians(theta)
+            cosTheta = cos(theta)
+            sinTheta = sin(theta)
+
+            spanMin = 0x7fffffff
+            spanMax = -spanMin
+
+            #   Loop to determine the span over which diagonal lines must be drawn.
+            for P in xyLists:
+                for j in range(0,len(P),2):
+                    #   rotated point, since the stripes may be at an angle.
+                    y = P[j+1]*cosTheta-P[j]*sinTheta
+                    spanMin = min(y,spanMin)
+                    spanMax = max(y,spanMax)
+
+            #   Turn the span into a discrete step range.
+            spanStart = int(floor(spanMin/spacing)) - 1
+            spanEnd  = int(floor(spanMax/spacing)) + 1
+
+            #   Loop to create all stripes.
+            for step in range(spanStart,spanEnd):
+                nodeX = []
+                stripeY = spacing*step
+
+                #   Loop to build a node list for one row of stripes.
+                for P in xyLists:
+                    k = len(P)-2    #start by comparing with the last point
+                    for j in range(0,len(P),2):
+                        a = P[k]
+                        b = P[k+1]
+                        a1 = a*cosTheta + b*sinTheta
+                        b1 = b*cosTheta - a*sinTheta
+                        x = P[j]
+                        y = P[j+1]
+
+                        x1 = x*cosTheta+y*sinTheta
+                        y1 = y*cosTheta-x*sinTheta
+
+                        #   Find the node, if any.
+                        if (b1<stripeY and y1>=stripeY) or y1<stripeY and b1>=stripeY:
+                            nodeX.append(a1+(x1-a1)*(stripeY-b1)/(y1-b1))
+
+                        k = j
+
+                nodeX.sort()
+
+                #   Loop to draw one row of line segments.
+                for j in range(0,len(nodeX),2):
+                    #   Rotate the points back to their original coordinate system.
+                    a = nodeX[j]*cosTheta - stripeY*sinTheta
+                    b = stripeY*cosTheta+nodeX[j]*sinTheta
+                    x = nodeX[j+1]*cosTheta - stripeY*sinTheta
+                    y = stripeY*cosTheta + nodeX[j+1]*sinTheta
+
+                    #Draw a single stripe segment.
+                    moveTo(a,b)
+                    lineTo(x,y)
+
 def numericXShift(tA,text,w,fontName,fontSize,encoding=None,pivotCharacter=decimalSymbol):
     dp = getattr(tA,'_dp',pivotCharacter)
     i = text.rfind(dp)
